function output = fftrans(sdata, npoint)
% fftrans vypocita rychlu fourierovu transformaciu
%
% sdata - navzorkovane data
% npoint - n-bodova fourierova transformacia

% inicializacia
if nargin == 1
    npoint = size(sdata, 2);
else
    sdatasize = size(sdatasize, 2);
    npointsize = size(npoint, 2);
    
    if npointsize > sdatasize
        % doplnenie nulami
        sdata = [sdata zeros(1, npointsize - sdatasize)];
    elseif npointsize < sdatasize
        % orezanie
        sdata = sdata(1, 1:npointsize);
    end
end

output = p_fftrans(sdata, npoint);

%=========================================
function output = p_fftrans(sdata, npoint)
% vypocet rychlej fourierovej transformacie

if npoint == 1
    output = sdata;
else
    ie = 2:2:npoint; io = 1:2:npoint; 
    even = sdata(ie); odd = sdata(io); 
    
    e = p_fftrans(even, npoint / 2);
    o = p_fftrans(odd, npoint / 2);
    
    w = exp(2 * pi * i / npoint); 
    output = [];
    for j = 0:npoint - 1
        v = w ^ j;
        index = mod(j, npoint / 2) + 1;
        h = e(index) + v * o(index);
        output = [output h];
    end
end

