% generate a complex signal
fs = 10000;                                % sampling rate
t = 0:1/fs:0.1;                            % sampling instants
x = sin(2*pi*1500*t) + sin(2*pi*4000*t);   % two sinusoids

% perform 1000-point transform
tic;
y = fft(x,1000);                           % y contains 1000 complex amplitudes
toc;
m = abs(y);                                % m = magnitude of sinusoids
p = unwrap(angle(y));              % p = phase of sinusoids, unwrap()
                                           % copes with 360 degree jumps

% plot first 500 points = 0..fs/2
f = (0:499)*fs/length(y);
subplot(2,1,1), plot(f,m(1:500))           % plot magnitudes
ylabel('Abs. Magnitude'), grid on
subplot(2,1,2), plot(f,p(1:500)*180/pi)    % plot phase in degrees
ylabel('Phase [Degrees]'), grid on
xlabel('Frequency [Hertz]')